View source: R/plotNFI_spatial.R
| plot.nfiMetrics_spatial | R Documentation |
Plot a spatial nfiMetrics object.
## S3 method for class 'nfiMetrics_spatial'
plot(x,
y = NULL, ...)
x |
A spatial |
y |
Optional character vector of variable names or numeric vector of column positions to plot; |
... |
Additional arguments passed to the internal spatial plotting engine, including options such as |
Wilson Lara [aut, cre] (ORCID: <https://orcid.org/0000-0003-3527-1380>), Cristobal Ordonez [aut] (ORCID: <https://orcid.org/0000-0001-5354-3760>), Aitor Vázquez-Veloso [aut] (ORCID: <https://orcid.org/0000-0003-0227-506X>), Felipe Bravo [aut] (ORCID: <https://orcid.org/0000-0001-7348-6695>)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.