update.inventoryMetrics: Update a stored inventoryMetrics call

update.inventoryMetricsR Documentation

Update a stored inventoryMetrics call

Description

Re-run inventoryMetrics from the call stored in a previous "inventoryMetrics" result while replacing one or more named arguments in .... This method supports reproducible re-evaluation of the selected backend and can either return the updated result or the reconstructed call.

Usage

## S3 method for class 'inventoryMetrics'
update(object, 
    ..., evaluate = TRUE)

Arguments

object

A "inventoryMetrics" object created by the updatable inventoryMetrics definition.

...

Named arguments used to replace entries in the stored call before evaluation.

evaluate

logical. If TRUE, evaluate the updated call and return the resulting object. If FALSE, return the reconstructed call without evaluation.

Value

A new "inventoryMetrics" object when

evaluate = TRUE; otherwise the updated call.

Author(s)

Wilson Lara [aut, cre] (ORCID: <https://orcid.org/0000-0003-3527-1380>), Cristobal Ordonez [aut] (ORCID: <https://orcid.org/0000-0001-5354-3760>), Aitor Vázquez-Veloso [aut] (ORCID: <https://orcid.org/0000-0003-0227-506X>), Felipe Bravo [aut] (ORCID: <https://orcid.org/0000-0001-7348-6695>)


basifoR documentation built on Aug. 26, 2026, 9:06 a.m.