This function can format tree diameters at breast height and tree
heights according to the sampling design of the Spanish National
Forest Inventory (SNFI). The function is used by other routines of
basifoR to derive tree metrics, see Details
section. Implementation of this function using data sets of the
SNFI can be burdensome. Use dendroMetrics instead to
recursively derive tree metrics.
dbhMetric(dbh, met = "d")numeric. A tree metric: mean diameter (mm), tree basal area
(m2 tree-1), number of trees (dimensionless), or
tree height (dm).
numeric. Either diameters at breast height
(mm) or tree heights (m). Vectors are
averaged. Zero values are formatted to NA.
character. Any of five metrics: mean diameter
at breast height ('d'), basal area
('ba'), number of trees ('n'), or tree
height ('h'). Default 'd'.
Wilson Lara <wilarhen@gmail.com> [aut, cre] (<https://orcid.org/0000-0003-3527-1380>), Cristobal Ordonez <a_cristo@pvs.uva.es> [aut] (<https://orcid.org/0000-0001-5354-3760>), Felipe Bravo <fbravo@pvs.uva.es> [aut] (<https://orcid.org/0000-0001-7348-6695>)
Replicates of tree diameter
'd' are averaged. The tree heights
'h' are formatted from mm to
dm for further evaluation of volume
equations. The basal areas are computed
transforming the diameters from mm to
cm and using the formula: ba (m2
tree-1 ha-1) = pi * d(cm)^2 * (4 *
1E4)^-1. The number of trees per hectare
'n' are calculated considering the
sample design of the NFI: each plot consists
of four concentric subplots with radii
5, 10, 15, and 25 m. The
minimum diameters recorded in the subplots
are 7.5, 12.5, 22.5, and 42.5
cm respectively. Considering these, any of
four estimates is printed: 127.32,
31.83, 14.15, or 5.09.
dbh <- dbhMetric(c(10.7, 11.5), 'h')# average tree height (dm)
Run the code above in your browser using DataLab