This function recursively implements dbhMetric on
data bases of the Spanish National Forest Inventory (NFI) to
derive a variety of tree metrics. Use metrics2Vol to
recursively derive the metrics plus over bark volumes.
data.frame containing columns which match the strings in
levels, plus the variables defined in var, including
the province pr (dimensionless), the diameter
d ('mm'), the tree height h ('dm'),
the basal area ba ('m2 tree-1'), the number of trees
by hectare n (dimensionless), and the tree dominant
height Hd ('m').
Arguments
nfi
character or data.frame. URL/path to a
compressed file of the NFI (.zip) having data of either
.dbf or .mdb file extensions, or a data frame such as that
produced by readNFI.
var
character. Metrics. These
can be five: (1) the
mean diameter 'd';
(2) the tree height
'h'; (3) the
basal area 'ba';
(4) the number of
trees per hectare
'n'; and (5)
the dominant height
'Hd', see Details
section in
dbhMetric for
better understanding of the
metrics units. Default
c('pr','d','h','ba','n','Hd').
levels
character. levels at which
the metrics are computed. Pattern
matching is supported. Cases are
ignored. Default
c('esta','espe') matches both
the sample plot 'Estadillos'
and tree species 'Especie'.,
...
Additional arguments in readNFI.
Author
Wilson Lara <wilarhen@gmail.com> [aut, cre] (<https://orcid.org/0000-0003-3527-1380>), Cristobal Ordonez <a_cristo@pvs.uva.es> [aut] (<https://orcid.org/0000-0001-5354-3760>), Felipe Bravo <fbravo@pvs.uva.es> [aut] (<https://orcid.org/0000-0001-7348-6695>)