| trees_per_ha.inventory_design | R Documentation |
Return the trees-per-hectare expansion factor for a tree measured under a generic inventory design.
## S3 method for class 'inventory_design'
trees_per_ha(design,
dbh_cm)
design |
Object of class |
dbh_cm |
|
It returns NA_real_ when all supplied diameters are
missing or when the resulting diameter is smaller than the
minimum threshold supported by the design.
A single numeric expansion factor in trees per hectare
taken from design$sf, or NA_real_ when the tree
does not belong to any tally tier.
Wilson Lara [aut, cre] (ORCID: <https://orcid.org/0000-0003-3527-1380>), Cristobal Ordonez [aut] (ORCID: <https://orcid.org/0000-0001-5354-3760>), Aitor Vázquez-Veloso [aut] (ORCID: <https://orcid.org/0000-0003-0227-506X>), Felipe Bravo [aut] (ORCID: <https://orcid.org/0000-0001-7348-6695>)
dsg <- new_inventory_design(sample_area_m2 = c(100, 400),
min_dbh_cm = c(0, 20),
name = "Example design")
trees_per_ha(dsg, 13)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.