| update.dendroMetrics | R Documentation |
Re-run dendroMetrics from the call stored
in a previous "dendroMetrics" result while replacing one or
more named arguments in .... This method supports reproducible
re-evaluation of the original workflow and can either return the
updated result or the reconstructed call.
## S3 method for class 'dendroMetrics'
update(object,
..., evaluate = TRUE)
object |
A |
... |
Named arguments used to replace entries in the stored call before evaluation. |
evaluate |
|
A new "dendroMetrics" object when
evaluate = TRUE; otherwise the updated call.
Wilson Lara [aut, cre] (ORCID: <https://orcid.org/0000-0003-3527-1380>), Cristobal Ordonez [aut] (ORCID: <https://orcid.org/0000-0001-5354-3760>), Aitor Vázquez-Veloso [aut] (ORCID: <https://orcid.org/0000-0003-0227-506X>), Felipe Bravo [aut] (ORCID: <https://orcid.org/0000-0001-7348-6695>)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.